parade.template.workspace.jupyter.ipython.profile\_parade.startup package
=========================================================================

Submodules
----------

parade.template.workspace.jupyter.ipython.profile\_parade.startup.00\-parade module
-----------------------------------------------------------------------------------

.. automodule:: parade.template.workspace.jupyter.ipython.profile_parade.startup.00-parade
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.template.workspace.jupyter.ipython.profile_parade.startup
    :members:
    :undoc-members:
    :show-inheritance:
